/*******************************************************************************
 * Copyright (c) 2004, 2008 Etish Limited.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Barbara Rosi-Schwartz (Etish Limited, UK) - initial API and implementation
 *     Joel Rosi-Schwartz (Etish Limited, UK) - initial API and implementation
 *******************************************************************************/
package org.eclipse.ormf.server.base.services.domain;

import java.io.Serializable;

import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Lob;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;
import javax.persistence.Version;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.eclipse.ormf.shared.util.logging.ILogger;
import org.eclipse.ormf.shared.util.logging.Logger;

@Entity(name = "ControlDocs")
@Table(name = "Control_Docs", schema = "useme", uniqueConstraints = @UniqueConstraint(columnNames = {
		"name", "project_id" }))
public class ControlDoc implements Serializable {
	/**
	 * 
	 */
	private static final long serialVersionUID = 1494020900126446908L;

	/**
	 * The instance of the logger for this class.
	 */
	private static final ILogger logger = Logger.Instance(ControlDoc.class);

	private Long id;

	/** persistent field */
	private String name;

	/** persistent field */
	private Short projectId;

	/** nullable persistent field */
	private Integer version;

	/** persistent field */
	private String xml;

	/** default constructor */
	public ControlDoc() {
	}

	/** minimal constructor */
	public ControlDoc(String name, Short projectId, String xml) {
		this.name = name;
		this.projectId = projectId;
		this.xml = xml;
	}

	@Override
	public boolean equals(Object other) {
		if ((this == other)) {
			return true;
		}
		if (!(other instanceof ControlDoc)) {
			return false;
		}
		final ControlDoc castOther = (ControlDoc) other;
		return new EqualsBuilder().append(getName(), castOther.getName())
				.append(getProjectId(), castOther.getProjectId()).isEquals();
	}

	@Id
	@Column(updatable = false, nullable = false)
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	public Long getId() {
		return id;
	}

	@Column(length = 64, nullable = false)
	@Basic(optional = false)
	public String getName() {
		return name;
	}

	@Column(name = "project_id", nullable = false)
	@Basic(optional = false)
	public Short getProjectId() {
		return projectId;
	}

	@Version
	protected Integer getVersion() {
		return version;
	}

	@Column(name = "the_xml", length = 512000, nullable = false)
	@Basic(optional = false)
	@Lob
	public String getXml() {
		return xml;
	}

	@Override
	public int hashCode() {
		return new HashCodeBuilder().append(getName()).append(getProjectId())
				.toHashCode();
	}

	protected void setId(Long id) {
		this.id = id;
	}

	protected void setName(String name) {
		this.name = name;
	}

	protected void setProjectId(Short projectId) {
		this.projectId = projectId;
	}

	protected void setVersion(Integer version) {
		this.version = version;
	}

	public void setXml(String xml) {
		this.xml = xml;
	}

	@Override
	public String toString() {
		return new ToStringBuilder(this).append("id", getId()).append("name",
				getName()).append("projectId", getProjectId()).toString();
	}
}