/*******************************************************************************
 * Copyright (c) 2004, 2008 Etish Limited.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Barbara Rosi-Schwartz (Etish Limited, UK) - initial API and implementation
 *     Joel Rosi-Schwartz (Etish Limited, UK) - initial API and implementation
 *******************************************************************************/
package org.eclipse.ormf.server.base.services.domain;

import java.io.Serializable;

import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;
import javax.persistence.Version;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.eclipse.ormf.shared.util.logging.ILogger;
import org.eclipse.ormf.shared.util.logging.Logger;

@Entity(name = "LovValues")
@Table(name = "Lov_Values", schema = "useme", uniqueConstraints = @UniqueConstraint(columnNames = {
		"item", "code", "language", "variant", "project_id" }))
public class LovValue implements Serializable {
	/**
	 * 
	 */
	private static final long serialVersionUID = -2709004046424453251L;

	/**
	 * The instance of the logger for this class.
	 */
	private static final ILogger logger = Logger.Instance(LovValue.class);

	/** persistent field */
	private String code;

	/** identifier field */
	private Long id;

	/** persistent field */
	private Short item;

	/** persistent field */
	private String language;

	/** persistent field */
	private Short projectId;

	/** nullable persistent field */
	private Short theSortOrder;

	/** persistent field */
	private String value;

	/** persistent field */
	private String variant;

	/** nullable persistent field */
	private Integer version;

	/** default constructor */
	protected LovValue() {
	}

	/** full constructor */
	public LovValue(Short item, String code, String language, String variant,
			Short projectId, Short sortOrder, String value) {
		this.item = item;
		this.code = code;
		this.language = language;
		this.variant = variant;
		this.projectId = projectId;
		theSortOrder = new Short(sortOrder);
		this.value = value;
	}

	@Override
	public boolean equals(Object other) {
		if ((this == other)) {
			return true;
		}

		if (!(other instanceof LovValue)) {
			return false;
		}

		final LovValue castOther = (LovValue) other;

		return new EqualsBuilder().append(getCode(), castOther.getCode())
				.append(getLanguage(), castOther.getLanguage()).append(
						getVariant(), castOther.getVariant()).append(
						getProjectId(), castOther.getProjectId()).isEquals();
	}

	@Basic(optional = false)
	@Column(length = 40, nullable = false)
	public String getCode() {
		return code;
	}

	@Id
	@Column(updatable = false, nullable = false)
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	public Long getId() {
		return id;
	}

	@Basic(optional = false)
	@Column(nullable = false)
	public Short getItem() {
		return item;
	}

	@Basic(optional = false)
	@Column(length = 60, nullable = false)
	public String getLanguage() {
		return language;
	}

	@Basic(optional = false)
	@Column(name = "project_id", nullable = false)
	public Short getProjectId() {
		return projectId;
	}

	@Column(name = "the_sort_order")
	public Short getTheSortOrder() {
		return theSortOrder;
	}

	@Basic(optional = false)
	@Column(length = 60, nullable = false)
	public String getValue() {
		return value;
	}

	@Basic(optional = false)
	@Column(nullable = false)
	public String getVariant() {
		return variant;
	}

	@Version
	protected Integer getVersion() {
		return version;
	}

	@Override
	public int hashCode() {
		return new HashCodeBuilder().append(getCode()).append(getLanguage())
				.append(getVariant()).append(getProjectId()).toHashCode();
	}

	protected void setCode(String code) {
		this.code = code;
	}

	protected void setId(Long id) {
		this.id = id;
	}

	protected void setItem(Short item) {
		this.item = item;
	}

	protected void setLanguage(String language) {
		this.language = language;
	}

	protected void setProjectId(Short projectId) {
		this.projectId = projectId;
	}

	protected void setTheSortOrder(Short sortOrder) {
		theSortOrder = sortOrder;
	}

	protected void setValue(String value) {
		this.value = value;
	}

	protected void setVariant(String variant) {
		this.variant = variant;
	}

	protected void setVersion(Integer version) {
		this.version = version;
	}

	@Override
	public String toString() {
		return new ToStringBuilder(this).append("id", getId()).append("code",
				getCode()).append("language", getLanguage()).append("variant",
				getVariant()).append("projectId", getProjectId()).toString();
	}
}