/*******************************************************************************
 * Copyright (c) 2008 Etish Limited.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Authors:
 *     Joel Rosi-Schwartz (Etish Limited, UK) <http://www.etish.org/>
 *******************************************************************************/
package org.eclipse.ormf.server.base.services.domain.internal;

import org.eclipse.ormf.server.base.services.domain.ControlDoc;
import org.eclipse.ormf.server.base.services.domain.DomainFactoryService;
import org.eclipse.ormf.server.base.services.domain.LovValue;
import org.eclipse.ormf.server.base.services.domain.ProjectRegistration;
import org.eclipse.ormf.server.base.services.domain.Relationship;
import org.eclipse.ormf.server.base.services.domain.ReqDoc;
import org.eclipse.ormf.server.base.services.domain.UsemeSession;
import org.eclipse.ormf.server.base.services.domain.User;

/**
 * @author joel
 * 
 */
public class DomainFactoryServiceImpl implements DomainFactoryService {

	/*
	 * @see org.eclipse.ormf.server.base.services.domain.DomainFactoryService#
	 * createControlDoc(java.lang.String, java.lang.Short, java.lang.String)
	 */
	public ControlDoc createControlDoc(String name, Short projectId, String xml) {
		return new ControlDoc(name, projectId, xml);
	}

	/*
	 * @see org.eclipse.ormf.server.base.services.domain.DomainFactoryService#
	 * createLovValue(java.lang.Short, java.lang.String, java.lang.String,
	 * java.lang.String, java.lang.Short, java.lang.Short, java.lang.String)
	 */
	public LovValue createLovValue(Short item, String code, String language,
			String variant, Short projectId, Short sortOrder, String value) {
		return new LovValue(item, code, language, variant, projectId,
				sortOrder, value);
	}

	/*
	 * @see org.eclipse.ormf.server.base.services.domain.DomainFactoryService#
	 * createProjectRegistration(java.lang.Short, java.lang.Boolean,
	 * org.eclipse.ormf.server.base.services.domain.User)
	 */
	public ProjectRegistration createProjectRegistration(Short projectId,
			Boolean projectAdmin, User user) {
		return new ProjectRegistration(projectId, projectAdmin, user);
	}

	/*
	 * @see org.eclipse.ormf.server.base.services.domain.DomainFactoryService#
	 * createRelationship(java.lang.Long, java.lang.Short, java.lang.Short,
	 * java.lang.Long, java.lang.Short, java.lang.Short, java.lang.Short,
	 * java.lang.Boolean, java.lang.Short)
	 */
	public Relationship createRelationship(Long consumerDocId,
			Short consumerDocType, Short consumerProjectId, Long providerDocId,
			Short providerDocType, Short providerElementId,
			Short providerProjectId, Boolean providerRdbms, Short stereotype) {
		return new Relationship(consumerDocId, consumerDocType,
				consumerProjectId, providerDocId, providerDocType,
				providerElementId, providerProjectId, providerRdbms, stereotype);
	}

	/*
	 * @see org.eclipse.ormf.server.base.services.domain.DomainFactoryService#
	 * createReqDoc(java.lang.Short, java.lang.Short, java.lang.String)
	 */
	public ReqDoc createReqDoc(Short projectId, Short type, String xml) {
		return new ReqDoc(projectId, type, xml);
	}

	/*
	 * @see org.eclipse.ormf.server.base.services.domain.DomainFactoryService#
	 * createUsemeSession(java.lang.String,
	 * org.eclipse.ormf.server.base.services.domain.User)
	 */
	public UsemeSession createUsemeSession(String hostId, User user) {
		return new UsemeSession(hostId, user);
	}

	/*
	 * @see
	 * org.eclipse.ormf.server.base.services.domain.DomainFactoryService#createUser
	 * (java.lang.String, java.lang.String, java.lang.String, java.lang.String,
	 * java.lang.Boolean)
	 */
	public User createUser(String uid, String password, String name,
			String email, Boolean sysAdmin) {
		return new User(uid, password, name, email, sysAdmin);
	}

}
